
(*
 * sxevent - Allow multiple events per day with pcboard and change
 *            'Slide Event' toggle and 'Suspense Period' values
 *
 *    Modification History
 *
 * Robert B. Browne, 27-Aug-90
 *   fixed logic error introduced in previous edit
 *   expanded function to include setting event suspense period
 *   changed errorlevel reporting to indicate current instead of next event
 *   updated to PCBoard v 14.5
 *
 * Skosch Penrose, 26-Dec-89
 * Samuel H. Smith, 12-Dec-87 (rev. 5-01-88)
 *)

const
   whoami = 'SXEVENT';
   version = 'Version 2.1 for PCBoard 14.5 01-Sep-90';
   dataname = 'SXEVENT.DAT';


{$i anystring.inc} (* general string declatation *)

{$i varstr.dcl}    (* variable allocation string library *)
{$i varstr.inc}

const
   max_event = 50;
   event_time = 113;
   slide_event = 116;
   suspense_time = 114;
var
   fd:       text;
   setup:    array[1..300] of varstring;
   event,slide,suspense:    array[1..max_event] of string[5];
   eventstr: string[5];
   events:   integer;
   eventno:  integer;
   this_event: integer;
   setup_entries: integer;

(* --------------------------------------------------------- *)
function StripComment(s: string): string;
var
   p: integer;

begin
     p := pos(' ',s);
     if p > 0 then
        s := copy(s, 1, p - 1);
     StripComment := s;
end;

(* --------------------------------------------------------- *)
procedure getline(i: integer);
   (* get a full line from the "basic" file *)
var
   str:  longstring;

begin
   if eof(fd) then
      str := ^Z
   else
      readln(fd,str);

   savestr(setup[i],str);
end;


(* --------------------------------------------------------- *)
procedure load_setup_file;
var
   i: integer;
begin
   assign(fd,'pcboard.dat');
   {$i-} reset(fd); {$i+}
   if ioresult <> 0 then
   begin
      writeln('Can''t open pcboard.dat!');
      halt(99);
   end;
   i := 0;
   while not eof(fd) do begin
    readln(fd);
    i := i + 1;
   end; {while}
   setup_entries := i;

   reset(fd);

   fillchar(setup,sizeof(setup),0);
   getline(1);

   if setup[1]^ <> '*** PCBoard Version 14.5 data file ***' then
   begin
      writeln('This program only works with pcboard 14.5!');
      halt(99);
   end;

   for i := 2 to setup_entries do
      getline(i);

   close(fd);
end;


(* --------------------------------------------------------- *)
procedure putl(i: integer);
begin
   writeln(fd,setup[i]^);
end;


(* --------------------------------------------------------- *)
procedure save_setup_file;
var
   i: integer;
begin
   assign(fd,'pcboard.dat');
   rewrite(fd);
   for i := 1 to setup_entries do
      putl(i);
   close(fd);
end;


(* --------------------------------------------------------- *)
procedure change_event_time;
var
   i: integer;
   c: integer;
   p: integer;
   l: integer;

begin
   assign(fd,dataname);
   {$i-} reset(fd); {$i+}
   if ioresult <> 0 then
   begin
      writeln('Can''t open ',dataname);
      halt(99);
   end;


   readln(fd);                { file header }
   readln(fd,eventstr);       { # of events }
   eventstr := StripComment(eventstr);
   Val(eventstr, events, c);  { convert string to integer }

   if c <> 0 then
   begin
      writeln('Error in event count');
      halt(99);
   end;
   for i := 1 to events do
   begin
      readln(fd,event[i]);      {event time}
      event[i] := StripComment(event[i]);
      readln(fd,slide[i]);      {event slide}
      slide[i] := StripComment(slide[i]);
      readln(fd,suspense[i]);   {suspense period minutes}
      suspense[i] := StripComment(suspense[i]);
   end;

   close(fd);

   for i := 1 to events do
   begin
      if setup[event_time]^ = event[i] then
      begin
         this_event := i;
         if i = events then
            eventno := 1
         else
            eventno := i + 1;
         savestr(setup[event_time], event[eventno]);
         writeln('Next event will be # ',eventno,' at ',event[eventno],'.');
         if slide[eventno] = 'Y' then
         begin
            savestr(setup[slide_event], '-1');
            writeln('Event Will Be SLIDING');
         end
         else
         begin
            savestr(setup[slide_event], '0');
            writeln('Event will NOT be Sliding');
         end;

         savestr(setup[suspense_time], suspense[eventno]);
         writeln('Board will Suspend Activity ',suspense[eventno],' minutes prior to event');

         exit;
      end;
   end;

   eventno := 1;
   this_event := events;
   writeln('Warning: Current event time does not match any time in sxevent.dat!');
   writeln('Next event will be at ',event[eventno],'.');
   savestr(setup[event_time], event[eventno]);
   savestr(setup[slide_event], slide[eventno]);
   savestr(setup[suspense_time], suspense[eventno]);
end;


(* --------------------------------------------------------- *)
begin
   writeln;
   writeln(whoami,' ',version);
   writeln('Courtesy of:  S.H.Smith  and  The Tool Shop BBS, (602) 279-2673.');
   writeln('Updated for PCB 14.5 by Bob Browne & Smart Office Solutions (SOS) (914) 576-6139');
   writeln;

   load_setup_file;
   change_event_time;
   save_setup_file;
   writeln('Current Event is # ',this_event,'.');
   writeln('Error level set to ',this_event,'.');
   halt(this_event);
end.

